summaryrefslogtreecommitdiff
path: root/Zend/zend_object_handlers.h
diff options
context:
space:
mode:
authorMarcus Boerger <helly@php.net>2003-11-10 16:14:44 +0000
committerMarcus Boerger <helly@php.net>2003-11-10 16:14:44 +0000
commit296529b886660ee95fc3182430164e7793028a3e (patch)
tree6db0ec498fe64fe2015e5f350a4489466b20461c /Zend/zend_object_handlers.h
parentda6d68d9190abe6ef863d4157fba5255a7a7be58 (diff)
downloadphp-git-296529b886660ee95fc3182430164e7793028a3e.tar.gz
Split isset/isempty for object property and object dimension hooking.
Diffstat (limited to 'Zend/zend_object_handlers.h')
-rw-r--r--Zend/zend_object_handlers.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/Zend/zend_object_handlers.h b/Zend/zend_object_handlers.h
index cf11b93574..3e98d7713b 100644
--- a/Zend/zend_object_handlers.h
+++ b/Zend/zend_object_handlers.h
@@ -53,10 +53,13 @@ typedef zval* (*zend_object_get_t)(zval *property TSRMLS_DC);
/* Used to check if a property of the object exists */
typedef int (*zend_object_has_property_t)(zval *object, zval *member, int check_empty TSRMLS_DC);
+/* Used to check if a dimension of the object exists */
+typedef int (*zend_object_has_dimension_t)(zval *object, zval *member, int check_empty TSRMLS_DC);
+
/* Used to remove a property of the object */
typedef void (*zend_object_unset_property_t)(zval *object, zval *member TSRMLS_DC);
/* Used to remove a property of the object */
typedef void (*zend_object_unset_dimension_t)(zval *object, zval *offset TSRMLS_DC);
/* Used to get hash of the properties of the object, as hash of zval's */
@@ -98,6 +101,7 @@ typedef struct _zend_object_handlers {
zend_object_set_t set;
zend_object_has_property_t has_property;
zend_object_unset_property_t unset_property;
+ zend_object_has_dimension_t has_dimension;
zend_object_unset_dimension_t unset_dimension;
zend_object_get_properties_t get_properties;
zend_object_get_method_t get_method;
@@ -53,10 +53,13 @@ typedef zval* (*zend_object_get_t)(zval *property TSRMLS_DC);
/* Used to remove a property of the object */
typedef void (*zend_object_unset_property_t)(zval *object, zval *member TSRMLS_DC);
-/* Used to remove a property of the object */
+/* Used to remove a dimension of the object */
typedef void (*zend_object_unset_dimension_t)(zval *object, zval *offset TSRMLS_DC);
/* Used to get hash of the properties of the object, as hash of zval's */